Documentation
¶
Index ¶
Constants ¶
const ( LPAREN = iota RPAREN LBRACE RBRACE COMMA DOT EQUAL PLUS STRING REGEXP POS GVAR LVAR KWD ID NAMESPACE OPEN FUNC TYPE PATH IMPORT OPTIONAL READ EOF ERROR NUM_LEXEMES )
Variables ¶
var LexemeName [NUM_LEXEMES]string
Functions ¶
This section is empty.
Types ¶
type Tokenizer ¶
type Tokenizer struct {
Source []byte
LineNumber int32
Lookahead *Token
// contains filtered or unexported fields
}
Represent a tokenizer with a struct containing the remaining source text and the line number. Easier than using a stateless tokenizing function that returns them as extra values and requires the parser to keep track of them.
func MakeTokenizer ¶
Click to show internal directories.
Click to hide internal directories.