Documentation
¶
Overview ¶
Package proto is a generated protocol buffer package.
It is generated from these files:
credentials.proto file.proto function.proto instruction.proto mixer.proto object.proto package.proto rewrite_rule.proto rewriter.proto slug.proto tritium.proto
It has these top-level messages:
Credentials
Index ¶
- Constants
- type Credentials
- func (m *Credentials) GetBase64() string
- func (m *Credentials) GetPassword() string
- func (m *Credentials) GetUser() string
- func (m *Credentials) IGetBase64() string
- func (m *Credentials) IGetPassword() string
- func (m *Credentials) IGetUser() string
- func (*Credentials) ProtoMessage()
- func (m *Credentials) Reset()
- func (m *Credentials) String() string
- type File
- type FileList
- type Function
- func (f *Function) BaseSignature(pkg2 protoface.Package) string
- func (fun *Function) Clone() protoface.Function
- func (fun *Function) DebugInfo(pkg2 protoface.Package) string
- func (f *Function) FullSignature(pkg2 protoface.Package) string
- func (m *Function) GetArgs() []*Function_Argument
- func (m *Function) GetBuiltIn() bool
- func (m *Function) GetDescription() string
- func (m *Function) GetFilename() string
- func (m *Function) GetInstruction() *Instruction
- func (m *Function) GetLineNumber() int32
- func (m *Function) GetName() string
- func (m *Function) GetNamespace() string
- func (m *Function) GetOpensType() string
- func (m *Function) GetOpensTypeId() int32
- func (m *Function) GetReturnType() string
- func (m *Function) GetReturnTypeId() int32
- func (m *Function) GetScopeType() string
- func (m *Function) GetScopeTypeId() int32
- func (m *Function) IGetBuiltIn() bool
- func (m *Function) IGetDescription() string
- func (m *Function) IGetFilename() string
- func (m *Function) IGetInstruction() protoface.Instruction
- func (m *Function) IGetLineNumber() int32
- func (m *Function) IGetName() string
- func (m *Function) IGetNamespace() string
- func (m *Function) IGetNthArg(index int) protoface.Function_Argument
- func (m *Function) IGetOpensType() string
- func (m *Function) IGetOpensTypeId() int32
- func (m *Function) IGetReturnType() string
- func (m *Function) IGetReturnTypeId() int32
- func (m *Function) IGetScopeType() string
- func (m *Function) IGetScopeTypeId() int32
- func (m *Function) INumArgs() int
- func (m *Function) ISetNthArg(index int, value protoface.Function_Argument)
- func (fun *Function) NameString() string
- func (fun *Function) OpensTypeString(pkg2 protoface.Package) string
- func (*Function) ProtoMessage()
- func (f *Function) RelocateCallsBy(offset int)
- func (f *Function) RelocateTypes(relocations map[int]int)
- func (m *Function) Reset()
- func (fun *Function) ReturnTypeString(pkg2 protoface.Package) string
- func (fun *Function) ScopeTypeString(pkg2 protoface.Package) string
- func (m *Function) String() string
- func (f *Function) Stub(pkg2 protoface.Package) string
- type FunctionArray
- func (m *FunctionArray) GetFunctions() []*Function
- func (m *FunctionArray) GetNthFunction(index int) protoface.Function
- func (*FunctionArray) ProtoMessage()
- func (m *FunctionArray) Reset()
- func (m *FunctionArray) SetNthFunction(index int, value protoface.Function)
- func (m *FunctionArray) String() string
- type Function_Argument
- func (m *Function_Argument) GetName() string
- func (m *Function_Argument) GetTypeId() int32
- func (m *Function_Argument) GetTypeString() string
- func (m *Function_Argument) IGetName() string
- func (m *Function_Argument) IGetTypeId() int32
- func (m *Function_Argument) IGetTypeString() string
- func (*Function_Argument) ProtoMessage()
- func (m *Function_Argument) Reset()
- func (m *Function_Argument) String() string
- type Instruction
- func FoldLeft(funcName string, base *Instruction, seq []*Instruction) (acc *Instruction)
- func ListInstructions(instrs ...*Instruction) []*Instruction
- func MakeBlock(children []*Instruction, lineNum int32) *Instruction
- func MakeComment(comment string, lineNum int32) *Instruction
- func MakeFunctionCall(name string, args []*Instruction, block []*Instruction, lineNum int32) *Instruction
- func MakeImport(path string, lineNum int32) *Instruction
- func MakeLocalVar(name string, val *Instruction, block []*Instruction, lineNum int32) *Instruction
- func MakePosition(pos string, lineNum int32) *Instruction
- func MakeText(text string, lineNum int32) *Instruction
- func (instr *Instruction) Append(more ...*Instruction)
- func (instr *Instruction) ConcatBlock(more *Instruction)
- func (instr *Instruction) ConcatList(more []*Instruction)
- func (m *Instruction) GetArguments() []*Instruction
- func (m *Instruction) GetChildren() []*Instruction
- func (ins *Instruction) GetFunction(pkg2 protoface.Package) protoface.Function
- func (m *Instruction) GetFunctionId() int32
- func (m *Instruction) GetIsUserCalled() bool
- func (m *Instruction) GetIsValid() bool
- func (m *Instruction) GetLineNumber() int32
- func (m *Instruction) GetNamespace() string
- func (m *Instruction) GetObjectId() int32
- func (m *Instruction) GetType() int32
- func (m *Instruction) GetTypeQualifier() string
- func (m *Instruction) GetValue() string
- func (m *Instruction) GetYieldTypeId() int32
- func (m *Instruction) IGetFunctionId() int32
- func (m *Instruction) IGetIsUserCalled() bool
- func (m *Instruction) IGetIsValid() bool
- func (m *Instruction) IGetLineNumber() int32
- func (m *Instruction) IGetNamespace() string
- func (m *Instruction) IGetNthArgument(index int) protoface.Instruction
- func (m *Instruction) IGetNthChild(index int) protoface.Instruction
- func (m *Instruction) IGetObjectId() int32
- func (m *Instruction) IGetType() int32
- func (m *Instruction) IGetTypeQualifier() string
- func (m *Instruction) IGetValue() string
- func (m *Instruction) IGetYieldTypeId() int32
- func (m *Instruction) INumArgs() int
- func (m *Instruction) INumChildren() int
- func (m *Instruction) ISetNthArgument(index int, value protoface.Instruction)
- func (m *Instruction) ISetNthChild(index int, value protoface.Instruction)
- func (ins *Instruction) Iterate(itFunc func(*Instruction))
- func (ins *Instruction) IterateAll(itFunc func(*Instruction))
- func (instr *Instruction) Namespaces() (nsList []string)
- func (*Instruction) ProtoMessage()
- func (m *Instruction) Reset()
- func (m *Instruction) String() string
- type Mixer
- func (mxr *Mixer) Clone() *Mixer
- func (m *Mixer) GetIsHttpTransformer() bool
- func (m *Mixer) GetName() string
- func (m *Mixer) GetPackage() *Package
- func (m *Mixer) GetPackagerVersion() int32
- func (m *Mixer) GetRewriters() []*File
- func (m *Mixer) GetVersion() string
- func (m *Mixer) Inspect(printFunctions bool)
- func (*Mixer) ProtoMessage()
- func (m *Mixer) Reset()
- func (m *Mixer) String() string
- func (m *Mixer) Unpack(path string)
- func (m *Mixer) Write(path string) (outputPath string, err error)
- type Package
- func (pkg *Package) AncestorOf(anc, dec int32) bool
- func (pkg *Package) FindDescendantType(thisType int32) int
- func (m *Package) GetDependencies() []string
- func (m *Package) GetFunctions() []*Function
- func (m *Package) GetName() string
- func (m *Package) GetNumExports() int32
- func (m *Package) GetPath() string
- func (pkg *Package) GetProtoTypeId(name *string) *int32
- func (pkg *Package) GetTypeId(name string) int
- func (pkg *Package) GetTypeName(id int32) string
- func (m *Package) GetTypes() []*Type
- func (m *Package) IGetDependencies() []string
- func (m *Package) IGetFunctions() []protoface.Function
- func (m *Package) IGetName() string
- func (m *Package) IGetNthFunction(index int) protoface.Function
- func (m *Package) IGetNthType(index int) protoface.Type
- func (m *Package) IGetPath() string
- func (m *Package) IGetTypes() []protoface.Type
- func (m *Package) ISetNthFunction(index int, value protoface.Function)
- func (m *Package) ISetNthType(index int, value protoface.Type)
- func (*Package) ProtoMessage()
- func (m *Package) Reset()
- func (m *Package) String() string
- type RewriteRule
- func (m *RewriteRule) GetCookieDomain() string
- func (m *RewriteRule) GetDirection() int32
- func (m *RewriteRule) GetProxy() string
- func (m *RewriteRule) GetUpstream() string
- func (m *RewriteRule) IGetCookieDomain() string
- func (m *RewriteRule) IGetDirection() int32
- func (m *RewriteRule) IGetProxy() string
- func (m *RewriteRule) IGetUpstream() string
- func (*RewriteRule) ProtoMessage()
- func (m *RewriteRule) Reset()
- func (m *RewriteRule) String() string
- type Rewriter
- type ScriptObject
- func (m *ScriptObject) GetFunctions() []*Function
- func (m *ScriptObject) GetLinked() bool
- func (m *ScriptObject) GetModule() string
- func (m *ScriptObject) GetName() string
- func (m *ScriptObject) GetRoot() *Instruction
- func (m *ScriptObject) GetScopeTypeId() int32
- func (m *ScriptObject) IGetLayer() string
- func (m *ScriptObject) IGetLinked() bool
- func (m *ScriptObject) IGetModule() string
- func (m *ScriptObject) IGetName() string
- func (m *ScriptObject) IGetNthFunction(index int) protoface.Function
- func (m *ScriptObject) IGetRoot() protoface.Instruction
- func (m *ScriptObject) IGetScopeTypeId() int32
- func (m *ScriptObject) ISetNthFunction(index int, value protoface.Function)
- func (obj *ScriptObject) ImportInstructions() []*Instruction
- func (obj *ScriptObject) Imports() []string
- func (*ScriptObject) ProtoMessage()
- func (m *ScriptObject) Reset()
- func (m *ScriptObject) String() string
- type Slug
- func (slug *Slug) FindInstruction(fileName string, lineNumber int) int
- func (m *Slug) GetActiveLayers() []string
- func (m *Slug) GetConfig() string
- func (m *Slug) GetCredentials() *Credentials
- func (m *Slug) GetJavaScript() string
- func (m *Slug) GetName() string
- func (m *Slug) GetRrules() []*RewriteRule
- func (m *Slug) GetSslWhitelist() []string
- func (m *Slug) GetTransformers() []*Transform
- func (m *Slug) GetVersion() string
- func (slug *Slug) IGetActiveLayers() []string
- func (slug *Slug) IGetConfig() string
- func (m *Slug) IGetCredentials() protoface.Credentials
- func (slug *Slug) IGetJavaScript() string
- func (m *Slug) IGetName() string
- func (m *Slug) IGetNthRrule(index int) protoface.RewriteRule
- func (m *Slug) IGetNthTransformer(index int) protoface.Transform
- func (m *Slug) IGetRrules() []protoface.RewriteRule
- func (m *Slug) IGetSslWhitelist() []string
- func (m *Slug) IGetVersion() string
- func (slug *Slug) ISetConfig(config string)
- func (slug *Slug) ISetJavaScript(js string)
- func (m *Slug) ISetNthRrule(index int, value protoface.RewriteRule)
- func (m *Slug) ISetNthTransformer(index int, value protoface.Transform)
- func (*Slug) ProtoMessage()
- func (m *Slug) Reset()
- func (m *Slug) String() string
- func (slug *Slug) WriteFile(filename string) (err error)
- type SlugInfo
- func (si *SlugInfo) IGetCustomer() string
- func (si *SlugInfo) IGetPath() string
- func (si *SlugInfo) IGetProject() string
- func (si *SlugInfo) IGetSize() int
- func (si *SlugInfo) IGetSlug() protoface.Slug
- func (si *SlugInfo) IGetTimestamp() time.Time
- func (si *SlugInfo) Reset()
- func (si *SlugInfo) Size() int
- type SubmixerInfo
- type Transform
- func (m *Transform) GetLayers() string
- func (m *Transform) GetObjects() []*ScriptObject
- func (m *Transform) GetPkg() *Package
- func (m *Transform) IGetLayers() string
- func (m *Transform) IGetNthObject(n int) protoface.ScriptObject
- func (m *Transform) IGetPkg() protoface.Package
- func (m *Transform) ISetNthObject(n int, s protoface.ScriptObject)
- func (*Transform) ProtoMessage()
- func (m *Transform) Reset()
- func (m *Transform) String() string
- type Type
Constants ¶
const ( RuleBidirection = "=>" RuleToProxy = "<-" RuleToUpstream = "->" )
const Default_RewriteRule_Direction int32 = 0
const Default_ScriptObject_Name string = "main"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Credentials ¶
type Credentials struct {
User *string `protobuf:"bytes,1,req,name=user" json:"user,omitempty"`
Password *string `protobuf:"bytes,2,req,name=password" json:"password,omitempty"`
Base64 *string `protobuf:"bytes,3,req,name=base64" json:"base64,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Credentials) GetBase64 ¶
func (m *Credentials) GetBase64() string
func (*Credentials) GetPassword ¶
func (m *Credentials) GetPassword() string
func (*Credentials) GetUser ¶
func (m *Credentials) GetUser() string
func (*Credentials) IGetBase64 ¶
func (m *Credentials) IGetBase64() string
func (*Credentials) IGetPassword ¶
func (m *Credentials) IGetPassword() string
func (*Credentials) IGetUser ¶
func (m *Credentials) IGetUser() string
func (*Credentials) ProtoMessage ¶
func (*Credentials) ProtoMessage()
func (*Credentials) Reset ¶
func (m *Credentials) Reset()
func (*Credentials) String ¶
func (m *Credentials) String() string
type File ¶
type File struct {
Path *string `protobuf:"bytes,1,req,name=path" json:"path,omitempty"`
Data []byte `protobuf:"bytes,2,req,name=data" json:"data,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func CollectFiles ¶
func (*File) AbsolutePath ¶
func (*File) ProtoMessage ¶
func (*File) ProtoMessage()
type Function ¶
type Function struct {
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
Description *string `protobuf:"bytes,11,opt,name=description" json:"description,omitempty"`
Filename *string `protobuf:"bytes,12,opt,name=filename" json:"filename,omitempty"`
LineNumber *int32 `protobuf:"varint,13,opt,name=line_number" json:"line_number,omitempty"`
Namespace *string `protobuf:"bytes,14,opt,name=namespace" json:"namespace,omitempty"`
// Linked
ScopeTypeId *int32 `protobuf:"varint,2,opt,name=scope_type_id" json:"scope_type_id,omitempty"`
ScopeType *string `protobuf:"bytes,8,opt,name=scope_type" json:"scope_type,omitempty"`
ReturnTypeId *int32 `protobuf:"varint,3,opt,name=return_type_id" json:"return_type_id,omitempty"`
ReturnType *string `protobuf:"bytes,9,opt,name=return_type" json:"return_type,omitempty"`
OpensTypeId *int32 `protobuf:"varint,4,opt,name=opens_type_id" json:"opens_type_id,omitempty"`
OpensType *string `protobuf:"bytes,10,opt,name=opens_type" json:"opens_type,omitempty"`
// Only informative post-linking
BuiltIn *bool `protobuf:"varint,5,opt,name=built_in" json:"built_in,omitempty"`
Args []*Function_Argument `protobuf:"bytes,6,rep,name=args" json:"args,omitempty"`
// Only for non-built-in functions
Instruction *Instruction `protobuf:"bytes,7,opt,name=instruction" json:"instruction,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Function) FullSignature ¶
prettier signatures than what `Stub` provides
func (*Function) GetArgs ¶
func (m *Function) GetArgs() []*Function_Argument
func (*Function) GetBuiltIn ¶
func (*Function) GetDescription ¶
func (*Function) GetFilename ¶
func (*Function) GetInstruction ¶
func (m *Function) GetInstruction() *Instruction
func (*Function) GetLineNumber ¶
func (*Function) GetNamespace ¶
func (*Function) GetOpensType ¶
func (*Function) GetOpensTypeId ¶
func (*Function) GetReturnType ¶
func (*Function) GetReturnTypeId ¶
func (*Function) GetScopeType ¶
func (*Function) GetScopeTypeId ¶
func (*Function) IGetBuiltIn ¶
func (*Function) IGetDescription ¶
func (*Function) IGetFilename ¶
func (*Function) IGetInstruction ¶
func (m *Function) IGetInstruction() protoface.Instruction
func (*Function) IGetLineNumber ¶
func (*Function) IGetNamespace ¶
func (*Function) IGetNthArg ¶
func (m *Function) IGetNthArg(index int) protoface.Function_Argument
func (*Function) IGetOpensType ¶
func (*Function) IGetOpensTypeId ¶
func (*Function) IGetReturnType ¶
func (*Function) IGetReturnTypeId ¶
func (*Function) IGetScopeType ¶
func (*Function) IGetScopeTypeId ¶
func (*Function) ISetNthArg ¶
func (m *Function) ISetNthArg(index int, value protoface.Function_Argument)
func (*Function) NameString ¶
func (*Function) OpensTypeString ¶
func (*Function) ProtoMessage ¶
func (*Function) ProtoMessage()
func (*Function) RelocateCallsBy ¶
func (*Function) RelocateTypes ¶
func (*Function) ReturnTypeString ¶
func (*Function) ScopeTypeString ¶
type FunctionArray ¶
type FunctionArray struct {
Functions []*Function `protobuf:"bytes,1,rep,name=functions" json:"functions,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*FunctionArray) GetFunctions ¶
func (m *FunctionArray) GetFunctions() []*Function
func (*FunctionArray) GetNthFunction ¶
func (m *FunctionArray) GetNthFunction(index int) protoface.Function
func (*FunctionArray) ProtoMessage ¶
func (*FunctionArray) ProtoMessage()
func (*FunctionArray) Reset ¶
func (m *FunctionArray) Reset()
func (*FunctionArray) SetNthFunction ¶
func (m *FunctionArray) SetNthFunction(index int, value protoface.Function)
func (*FunctionArray) String ¶
func (m *FunctionArray) String() string
type Function_Argument ¶
type Function_Argument struct {
TypeId *int32 `protobuf:"varint,1,opt,name=type_id" json:"type_id,omitempty"`
TypeString *string `protobuf:"bytes,2,opt,name=type_string" json:"type_string,omitempty"`
Name *string `protobuf:"bytes,3,opt,name=name" json:"name,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Function_Argument) GetName ¶
func (m *Function_Argument) GetName() string
func (*Function_Argument) GetTypeId ¶
func (m *Function_Argument) GetTypeId() int32
func (*Function_Argument) GetTypeString ¶
func (m *Function_Argument) GetTypeString() string
func (*Function_Argument) IGetName ¶
func (m *Function_Argument) IGetName() string
func (*Function_Argument) IGetTypeId ¶
func (m *Function_Argument) IGetTypeId() int32
func (*Function_Argument) IGetTypeString ¶
func (m *Function_Argument) IGetTypeString() string
func (*Function_Argument) ProtoMessage ¶
func (*Function_Argument) ProtoMessage()
func (*Function_Argument) Reset ¶
func (m *Function_Argument) Reset()
func (*Function_Argument) String ¶
func (m *Function_Argument) String() string
type Instruction ¶
type Instruction struct {
Type *int32 `protobuf:"varint,1,req,name=type" json:"type,omitempty"`
Value *string `protobuf:"bytes,2,opt,name=value" json:"value,omitempty"`
// only used if we are an import and we're all linked into an Transform
ObjectId *int32 `protobuf:"varint,3,opt,name=object_id" json:"object_id,omitempty"`
Children []*Instruction `protobuf:"bytes,4,rep,name=children" json:"children,omitempty"`
Arguments []*Instruction `protobuf:"bytes,5,rep,name=arguments" json:"arguments,omitempty"`
// Linked: Function Reference
// Until this happens, value says the function call name
FunctionId *int32 `protobuf:"varint,6,opt,name=function_id" json:"function_id,omitempty"`
LineNumber *int32 `protobuf:"varint,7,opt,name=line_number" json:"line_number,omitempty"`
// Used for yield() calls, because we need to know parent type
YieldTypeId *int32 `protobuf:"varint,8,opt,name=yield_type_id" json:"yield_type_id,omitempty"`
IsValid *bool `protobuf:"varint,9,opt,name=is_valid" json:"is_valid,omitempty"`
// used for function calls and variable references
Namespace *string `protobuf:"bytes,10,opt,name=namespace" json:"namespace,omitempty"`
TypeQualifier *string `protobuf:"bytes,11,opt,name=type_qualifier" json:"type_qualifier,omitempty"`
IsUserCalled *bool `protobuf:"varint,12,opt,name=is_user_called" json:"is_user_called,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func FoldLeft ¶
func FoldLeft(funcName string, base *Instruction, seq []*Instruction) (acc *Instruction)
func ListInstructions ¶
func ListInstructions(instrs ...*Instruction) []*Instruction
func MakeBlock ¶
func MakeBlock(children []*Instruction, lineNum int32) *Instruction
func MakeComment ¶
func MakeComment(comment string, lineNum int32) *Instruction
func MakeFunctionCall ¶
func MakeFunctionCall(name string, args []*Instruction, block []*Instruction, lineNum int32) *Instruction
func MakeImport ¶
func MakeImport(path string, lineNum int32) *Instruction
func MakeLocalVar ¶
func MakeLocalVar(name string, val *Instruction, block []*Instruction, lineNum int32) *Instruction
func MakePosition ¶
func MakePosition(pos string, lineNum int32) *Instruction
func MakeText ¶
func MakeText(text string, lineNum int32) *Instruction
func (*Instruction) Append ¶
func (instr *Instruction) Append(more ...*Instruction)
func (*Instruction) ConcatBlock ¶
func (instr *Instruction) ConcatBlock(more *Instruction)
func (*Instruction) ConcatList ¶
func (instr *Instruction) ConcatList(more []*Instruction)
func (*Instruction) GetArguments ¶
func (m *Instruction) GetArguments() []*Instruction
func (*Instruction) GetChildren ¶
func (m *Instruction) GetChildren() []*Instruction
func (*Instruction) GetFunction ¶
func (ins *Instruction) GetFunction(pkg2 protoface.Package) protoface.Function
func (*Instruction) GetFunctionId ¶
func (m *Instruction) GetFunctionId() int32
func (*Instruction) GetIsUserCalled ¶
func (m *Instruction) GetIsUserCalled() bool
func (*Instruction) GetIsValid ¶
func (m *Instruction) GetIsValid() bool
func (*Instruction) GetLineNumber ¶
func (m *Instruction) GetLineNumber() int32
func (*Instruction) GetNamespace ¶
func (m *Instruction) GetNamespace() string
func (*Instruction) GetObjectId ¶
func (m *Instruction) GetObjectId() int32
func (*Instruction) GetType ¶
func (m *Instruction) GetType() int32
func (*Instruction) GetTypeQualifier ¶
func (m *Instruction) GetTypeQualifier() string
func (*Instruction) GetValue ¶
func (m *Instruction) GetValue() string
func (*Instruction) GetYieldTypeId ¶
func (m *Instruction) GetYieldTypeId() int32
func (*Instruction) IGetFunctionId ¶
func (m *Instruction) IGetFunctionId() int32
func (*Instruction) IGetIsUserCalled ¶
func (m *Instruction) IGetIsUserCalled() bool
func (*Instruction) IGetIsValid ¶
func (m *Instruction) IGetIsValid() bool
func (*Instruction) IGetLineNumber ¶
func (m *Instruction) IGetLineNumber() int32
func (*Instruction) IGetNamespace ¶
func (m *Instruction) IGetNamespace() string
func (*Instruction) IGetNthArgument ¶
func (m *Instruction) IGetNthArgument(index int) protoface.Instruction
func (*Instruction) IGetNthChild ¶
func (m *Instruction) IGetNthChild(index int) protoface.Instruction
func (*Instruction) IGetObjectId ¶
func (m *Instruction) IGetObjectId() int32
func (*Instruction) IGetType ¶
func (m *Instruction) IGetType() int32
func (*Instruction) IGetTypeQualifier ¶
func (m *Instruction) IGetTypeQualifier() string
func (*Instruction) IGetValue ¶
func (m *Instruction) IGetValue() string
func (*Instruction) IGetYieldTypeId ¶
func (m *Instruction) IGetYieldTypeId() int32
func (*Instruction) INumArgs ¶
func (m *Instruction) INumArgs() int
func (*Instruction) INumChildren ¶
func (m *Instruction) INumChildren() int
func (*Instruction) ISetNthArgument ¶
func (m *Instruction) ISetNthArgument(index int, value protoface.Instruction)
func (*Instruction) ISetNthChild ¶
func (m *Instruction) ISetNthChild(index int, value protoface.Instruction)
func (*Instruction) Iterate ¶
func (ins *Instruction) Iterate(itFunc func(*Instruction))
func (*Instruction) IterateAll ¶
func (ins *Instruction) IterateAll(itFunc func(*Instruction))
func (*Instruction) Namespaces ¶
func (instr *Instruction) Namespaces() (nsList []string)
func (*Instruction) ProtoMessage ¶
func (*Instruction) ProtoMessage()
func (*Instruction) Reset ¶
func (m *Instruction) Reset()
func (*Instruction) String ¶
func (m *Instruction) String() string
type Mixer ¶
type Mixer struct {
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
Version *string `protobuf:"bytes,2,req,name=version" json:"version,omitempty"`
Rewriters []*File `protobuf:"bytes,3,rep,name=rewriters" json:"rewriters,omitempty"`
Package *Package `protobuf:"bytes,4,opt,name=package" json:"package,omitempty"`
// For the new packaging system -- AL 2013/03/21
PackagerVersion *int32 `protobuf:"varint,5,opt,name=packager_version" json:"packager_version,omitempty"`
IsHttpTransformer *bool `protobuf:"varint,6,opt,name=is_http_transformer" json:"is_http_transformer,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Mixer) GetIsHttpTransformer ¶
func (*Mixer) GetPackage ¶
func (*Mixer) GetPackagerVersion ¶
func (*Mixer) GetRewriters ¶
func (*Mixer) GetVersion ¶
func (*Mixer) ProtoMessage ¶
func (*Mixer) ProtoMessage()
type Package ¶
type Package struct {
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
Functions []*Function `protobuf:"bytes,2,rep,name=functions" json:"functions,omitempty"`
Types []*Type `protobuf:"bytes,3,rep,name=types" json:"types,omitempty"`
// Only used in non-linked combined packages
Dependencies []string `protobuf:"bytes,4,rep,name=dependencies" json:"dependencies,omitempty"`
// The following field is for nicer error messages
Path *string `protobuf:"bytes,5,opt,name=path" json:"path,omitempty"`
// specify which chunk of functions to export
NumExports *int32 `protobuf:"varint,6,opt,name=num_exports" json:"num_exports,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Structure representing a package of Tritium types and functions.
This is both used to store different packages headers and info (base, libxml, node, etc) and is used in an Transform to bundle together needed headers, functions, etc
func (*Package) AncestorOf ¶
assumes that the ID of a given type will be >= to the IDs of its ancestors
func (*Package) FindDescendantType ¶
TODO(SJ) : This should really return a list of descendants
func (*Package) GetDependencies ¶
func (*Package) GetFunctions ¶
func (*Package) GetNumExports ¶
func (*Package) GetProtoTypeId ¶
func (*Package) GetTypeName ¶
func (*Package) IGetDependencies ¶
func (*Package) IGetFunctions ¶
func (*Package) ISetNthFunction ¶
func (*Package) ProtoMessage ¶
func (*Package) ProtoMessage()
type RewriteRule ¶
type RewriteRule struct {
Proxy *string `protobuf:"bytes,1,opt,name=proxy" json:"proxy,omitempty"`
Upstream *string `protobuf:"bytes,2,opt,name=upstream" json:"upstream,omitempty"`
Direction *int32 `protobuf:"varint,3,opt,name=direction,def=0" json:"direction,omitempty"`
CookieDomain *string `protobuf:"bytes,4,opt,name=cookie_domain" json:"cookie_domain,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func ReadRewriteRules ¶
func ReadRewriteRules(rules []string) []*RewriteRule
func (*RewriteRule) GetCookieDomain ¶
func (m *RewriteRule) GetCookieDomain() string
func (*RewriteRule) GetDirection ¶
func (m *RewriteRule) GetDirection() int32
func (*RewriteRule) GetProxy ¶
func (m *RewriteRule) GetProxy() string
func (*RewriteRule) GetUpstream ¶
func (m *RewriteRule) GetUpstream() string
func (*RewriteRule) IGetCookieDomain ¶
func (m *RewriteRule) IGetCookieDomain() string
func (*RewriteRule) IGetDirection ¶
func (m *RewriteRule) IGetDirection() int32
func (*RewriteRule) IGetProxy ¶
func (m *RewriteRule) IGetProxy() string
func (*RewriteRule) IGetUpstream ¶
func (m *RewriteRule) IGetUpstream() string
func (*RewriteRule) ProtoMessage ¶
func (*RewriteRule) ProtoMessage()
func (*RewriteRule) Reset ¶
func (m *RewriteRule) Reset()
func (*RewriteRule) String ¶
func (m *RewriteRule) String() string
type Rewriter ¶
type Rewriter struct {
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
Templates []*File `protobuf:"bytes,2,rep,name=templates" json:"templates,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Rewriter) GetTemplates ¶
func (*Rewriter) ProtoMessage ¶
func (*Rewriter) ProtoMessage()
type ScriptObject ¶
type ScriptObject struct {
Name *string `protobuf:"bytes,1,opt,name=name,def=main" json:"name,omitempty"`
Root *Instruction `protobuf:"bytes,2,opt,name=root" json:"root,omitempty"`
Functions []*Function `protobuf:"bytes,3,rep,name=functions" json:"functions,omitempty"`
ScopeTypeId *int32 `protobuf:"varint,4,opt,name=scope_type_id" json:"scope_type_id,omitempty"`
Linked *bool `protobuf:"varint,5,opt,name=linked" json:"linked,omitempty"`
Module *string `protobuf:"bytes,6,opt,name=module" json:"module,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Object representing a script Possibly linked or not
func (*ScriptObject) GetFunctions ¶
func (m *ScriptObject) GetFunctions() []*Function
func (*ScriptObject) GetLinked ¶
func (m *ScriptObject) GetLinked() bool
func (*ScriptObject) GetModule ¶
func (m *ScriptObject) GetModule() string
func (*ScriptObject) GetName ¶
func (m *ScriptObject) GetName() string
func (*ScriptObject) GetRoot ¶
func (m *ScriptObject) GetRoot() *Instruction
func (*ScriptObject) GetScopeTypeId ¶
func (m *ScriptObject) GetScopeTypeId() int32
func (*ScriptObject) IGetLayer ¶
func (m *ScriptObject) IGetLayer() string
func (*ScriptObject) IGetLinked ¶
func (m *ScriptObject) IGetLinked() bool
func (*ScriptObject) IGetModule ¶
func (m *ScriptObject) IGetModule() string
func (*ScriptObject) IGetName ¶
func (m *ScriptObject) IGetName() string
func (*ScriptObject) IGetNthFunction ¶
func (m *ScriptObject) IGetNthFunction(index int) protoface.Function
func (*ScriptObject) IGetRoot ¶
func (m *ScriptObject) IGetRoot() protoface.Instruction
func (*ScriptObject) IGetScopeTypeId ¶
func (m *ScriptObject) IGetScopeTypeId() int32
func (*ScriptObject) ISetNthFunction ¶
func (m *ScriptObject) ISetNthFunction(index int, value protoface.Function)
func (*ScriptObject) ImportInstructions ¶
func (obj *ScriptObject) ImportInstructions() []*Instruction
func (*ScriptObject) Imports ¶
func (obj *ScriptObject) Imports() []string
func (*ScriptObject) ProtoMessage ¶
func (*ScriptObject) ProtoMessage()
func (*ScriptObject) Reset ¶
func (m *ScriptObject) Reset()
func (*ScriptObject) String ¶
func (m *ScriptObject) String() string
type Slug ¶
type Slug struct {
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
Version *string `protobuf:"bytes,2,req,name=version" json:"version,omitempty"`
Transformers []*Transform `protobuf:"bytes,3,rep,name=transformers" json:"transformers,omitempty"`
Rrules []*RewriteRule `protobuf:"bytes,4,rep,name=rrules" json:"rrules,omitempty"`
SslWhitelist []string `protobuf:"bytes,5,rep,name=ssl_whitelist" json:"ssl_whitelist,omitempty"`
Credentials *Credentials `protobuf:"bytes,6,opt,name=credentials" json:"credentials,omitempty"`
ActiveLayers []string `protobuf:"bytes,7,rep,name=active_layers" json:"active_layers,omitempty"`
JavaScript *string `protobuf:"bytes,8,opt,name=java_script" json:"java_script,omitempty"`
Config *string `protobuf:"bytes,9,opt,name=config" json:"config,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*Slug) FindInstruction ¶
func (*Slug) GetActiveLayers ¶
func (*Slug) GetCredentials ¶
func (m *Slug) GetCredentials() *Credentials
func (*Slug) GetJavaScript ¶
func (*Slug) GetRrules ¶
func (m *Slug) GetRrules() []*RewriteRule
func (*Slug) GetSslWhitelist ¶
func (*Slug) GetTransformers ¶
func (*Slug) GetVersion ¶
func (*Slug) IGetActiveLayers ¶
func (*Slug) IGetConfig ¶
func (*Slug) IGetCredentials ¶
func (m *Slug) IGetCredentials() protoface.Credentials
func (*Slug) IGetJavaScript ¶
func (*Slug) IGetNthRrule ¶
func (m *Slug) IGetNthRrule(index int) protoface.RewriteRule
func (*Slug) IGetRrules ¶
func (m *Slug) IGetRrules() []protoface.RewriteRule
func (*Slug) IGetSslWhitelist ¶
func (*Slug) IGetVersion ¶
func (*Slug) ISetConfig ¶
func (*Slug) ISetJavaScript ¶
func (*Slug) ISetNthRrule ¶
func (m *Slug) ISetNthRrule(index int, value protoface.RewriteRule)
func (*Slug) ISetNthTransformer ¶
func (*Slug) ProtoMessage ¶
func (*Slug) ProtoMessage()
type SlugInfo ¶
type SlugInfo struct {
Slug *Slug
SlugSize int
Timestamp time.Time
Customer string
Project string
Path string
}
func NewSlugInfo ¶
func NewSlugInfo() *SlugInfo
func (*SlugInfo) IGetCustomer ¶
func (*SlugInfo) IGetProject ¶
func (*SlugInfo) IGetTimestamp ¶
type SubmixerInfo ¶
type SubmixerInfo struct {
Name *string `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
Version *string `protobuf:"bytes,2,req,name=version" json:"version,omitempty"`
Offset *int32 `protobuf:"varint,3,req,name=offset" json:"offset,omitempty"`
Length *int32 `protobuf:"varint,4,req,name=length" json:"length,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
func (*SubmixerInfo) GetLength ¶
func (m *SubmixerInfo) GetLength() int32
func (*SubmixerInfo) GetName ¶
func (m *SubmixerInfo) GetName() string
func (*SubmixerInfo) GetOffset ¶
func (m *SubmixerInfo) GetOffset() int32
func (*SubmixerInfo) GetVersion ¶
func (m *SubmixerInfo) GetVersion() string
func (*SubmixerInfo) ProtoMessage ¶
func (*SubmixerInfo) ProtoMessage()
func (*SubmixerInfo) Reset ¶
func (m *SubmixerInfo) Reset()
func (*SubmixerInfo) String ¶
func (m *SubmixerInfo) String() string
type Transform ¶
type Transform struct {
Objects []*ScriptObject `protobuf:"bytes,1,rep,name=objects" json:"objects,omitempty"`
Pkg *Package `protobuf:"bytes,2,req,name=pkg" json:"pkg,omitempty"`
Layers *string `protobuf:"bytes,3,opt" json:"Layers,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
A post-linking object for execution
func (*Transform) GetObjects ¶
func (m *Transform) GetObjects() []*ScriptObject
func (*Transform) IGetLayers ¶
func (*Transform) IGetNthObject ¶
func (m *Transform) IGetNthObject(n int) protoface.ScriptObject
func (*Transform) ISetNthObject ¶
func (m *Transform) ISetNthObject(n int, s protoface.ScriptObject)
func (*Transform) ProtoMessage ¶
func (*Transform) ProtoMessage()
type Type ¶
type Type struct {
Name *string `protobuf:"bytes,1,opt,name=name" json:"name,omitempty"`
Implements *int32 `protobuf:"varint,2,opt,name=implements" json:"implements,omitempty"`
XXX_unrecognized []byte `json:"-"`
}
Core data types must be enumerated in the message
func (*Type) GetImplements ¶
func (*Type) IGetImplements ¶
func (*Type) ProtoMessage ¶
func (*Type) ProtoMessage()
Source Files
¶
- credentials.pb.go
- credentials_interface.go
- file.go
- file.pb.go
- filelist.go
- function.go
- function.pb.go
- function_interface.go
- instruction.go
- instruction.pb.go
- instruction_interface.go
- mixer.go
- mixer.pb.go
- object.go
- object.pb.go
- object_interface.go
- package.go
- package.pb.go
- package_interface.go
- rewrite_rule.go
- rewrite_rule.pb.go
- rewrite_rule_interface.go
- rewriter.pb.go
- slug.go
- slug.pb.go
- slug_interface.go
- tritium.pb.go
- tritium_interface.go